powfacpy.PFStringManipuilation — powfacpy 0.0.1 documentation

# powfacpy.PFStringManipuilation

class powfacpy.PFStringManipuilation
  __init__()

  Methods

  `__init__`() |
  `delete_classes`(path) |
  `format_full_path`(path, pf_interface) | Takes the full path (including user and project) and returns the path relative to the currently active project. Example: input path: username.IntUserpowfacpy_base.IntPrjNetwork Model.IntPrjfolderNetwork Data.IntPrjfolderGrid.ElmNetTerminal 1.ElmTerm output: Network ModelNetwork DataGridTerminal 1 .
  `handle_path`(path) |
  `replace_between_characters`(char1, char2, ...) |